==> 1.0.1.tar.gz: android/src/main/kotlin/com/wluper/wluper_plugin_flutter/sdk/WluperSDK.kt <==
package com.wluper.sdk

import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.speech.RecognitionListener
import android.speech.RecognizerIntent
import android.speech.SpeechRecognizer
import android.util.Log
import com.example.wluper_plugin_flutter.sdk.utils.WluperLogKey
import com.example.wluper_plugin_flutter.sdk.utils.WluperLogManager
import com.wluper.wluper_sdk.models.BodyUnderstand
import com.wluper.wluper_sdk.models.WluperLog
import com.wluper.wluper_sdk.network.TUApi
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.observers.DisposableSingleObserver
import io.reactivex.schedulers.Schedulers
import java.util.*

class WluperSDK(context: Context, _listener : WluperInterface, x_api_key:String) : RecognitionListener {
    var voiceIntent:Intent
    var speechRecognizer:SpeechRecognizer
    val _context:Context
    var listener: WluperInterface
    var api:TUApi
    var spokenText:String
    lateinit var wluperLogManager: WluperLogManager
    lateinit var session_id:String


    init {
        _context = context
        speechRecognizer = SpeechRecognizer.createSpeechRecognizer(context)
        speechRecognizer.setRecognitionListener(this)
        voiceIntent = Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH)
        voiceIntent.putExtra("android.speech.extra.DICTATION_MODE", true)
        voiceIntent.putExtra(RecognizerIntent.EXTRA_PARTIAL_RESULTS, true)
        voiceIntent.putExtra(RecognizerIntent.EXTRA_LANGUAGE, "en-US")
        listener = _listener
        spokenText=""
        api = TUApi.create(x_api_key)
    }

    fun setWluperLogBase(_wluperLog: WluperLog){
        wluperLogManager = WluperLogManager(_wluperLog);
    }

    fun startListening() {
        session_id = UUID.randomUUID().toString();
        speechRecognizer.startListening(voiceIntent)
         wluperLogManager?.let{
             it.post_event(WluperLogKey.ASR_KEY,WluperLogKey.ASR_START_LISTENING, session_id)
         }
    }

    fun cancelListening(){
        speechRecognizer.cancel()
        listener.WluperLiveText("")
        spokenText=""
        wluperLogManager?.let{
            it.post_event(WluperLogKey.ASR_KEY,WluperLogKey.ASR_CANCEL_LISTENING, session_id)
        }
    }

    fun wluperTU(text:String){
        val bodyUnderstand = BodyUnderstand( query = text)
        val call: DisposableSingleObserver<Any> = api.understand(bodyUnderstand)
        .subscribeOn(Schedulers.io())
        .observeOn(AndroidSchedulers.mainThread())
        .subscribeWith(object : DisposableSingleObserver<Any>(){
            override fun onSuccess(value: Any) {
                listener.WluperTree(value)
                wluperLogManager?.let{
                    it.post_event(WluperLogKey.NLU_KEY,value.toString(), session_id)
                }
            }
            override fun onError(e: Throwable) {
                listener.WluperError(e!!.message.toString())
                wluperLogManager?.let{
                    it.post_event(WluperLogKey.NLU_ERROR_KEY,e!!.message.toString(), session_id)
                }
            }
          }
        )
    }

    override fun onResults(results: Bundle?) {
        spokenText = getText(results)
        if (spokenText!="") {
            listener.WluperLiveText(spokenText)
        }
    }

    override fun onError(error: Int) {
        listener.WluperError("SpeechRecognizer: "+error)
        wluperLogManager?.let{
            it.post_event(WluperLogKey.ASR_ERROR_KEY,"SpeechRecognizer: "+error, session_id)
        }
    }

    override fun onReadyForSpeech(params: Bundle?) {
        listener.WluperASR("SpeechRecognizer: onReadyForSpeech");
        wluperLogManager?.let{
            it.post_event(WluperLogKey.ASR_KEY,WluperLogKey.ASR_READY_TO_SPEECH, session_id)
        }
    }

    override fun onBeginningOfSpeech() {}

    override fun onRmsChanged(rmsdB: Float) {}

    override fun onBufferReceived(buffer: ByteArray?) {}

    override fun onEndOfSpeech() {
        listener.WluperEndOfSpeech()
        wluperLogManager?.let{
            it.post_event(WluperLogKey.ASR_KEY,WluperLogKey.ASR_END_OF_SPEECH, session_id)
        }
    }

    override fun onPartialResults(partialResults: Bundle?) {
        spokenText = getText(partialResults)
        if (spokenText!="") {
            listener.WluperLiveText(spokenText)
        }
    }

    override fun onEvent(eventType: Int, params: Bundle?) { }

    private fun getText(speechBundle: Bundle?) : String {
        val userSaid = speechBundle?.getStringArrayList(SpeechRecognizer.RESULTS_RECOGNITION)
        return userSaid?.get(0) as String?: ""
    }


}

==> 1.1.0.tar.gz: android/src/main/kotlin/com/wluper/wluper_plugin_flutter/sdk/WluperSDK.kt <==
package com.wluper.wluper_plugin_flutter.sdk

import android.content.Context
import android.content.Intent
import android.os.Bundle
import android.speech.RecognitionListener
import android.speech.RecognizerIntent
import android.speech.SpeechRecognizer
import android.util.Log
import com.wluper.wluper_plugin_flutter.sdk.utils.WluperLogKey
import com.wluper.wluper_plugin_flutter.sdk.utils.WluperLogManager
import com.wluper.wluper_plugin_flutter.sdk.models.BodyUnderstand
import com.wluper.wluper_plugin_flutter.sdk.models.WluperLog
import com.wluper.wluper_plugin_flutter.sdk.network.TUApi
import com.wluper.wluper_plugin_flutter.sdk.network.LOGApi
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.observers.DisposableSingleObserver
import io.reactivex.schedulers.Schedulers
import java.util.*

class WluperSDK(context: Context, _listener : WluperInterface, client_id:String, x_api_key:String, log_api_key:String) : RecognitionListener {
    var voiceIntent:Intent
    var speechRecognizer:SpeechRecognizer
    val _context:Context
    var listener: WluperInterface

    var tu_api:TUApi
    var log_api:LOGApi

    var spokenText:String
    lateinit var wluperLogManager: WluperLogManager
    lateinit var session_id:String


    init {
        _context = context
        speechRecognizer = SpeechRecognizer.createSpeechRecognizer(context)
        speechRecognizer.setRecognitionListener(this)
        voiceIntent = Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH)
        voiceIntent.putExtra("android.speech.extra.DICTATION_MODE", true)
        voiceIntent.putExtra(RecognizerIntent.EXTRA_PARTIAL_RESULTS, true)
        voiceIntent.putExtra(RecognizerIntent.EXTRA_LANGUAGE, "en-US")
        listener = _listener
        spokenText=""
        
        tu_api = TUApi.create(client_id,x_api_key)

        log_api = LOGApi.create(client_id,log_api_key)
    }

    fun setWluperLogBase(_wluperLog: WluperLog){
        wluperLogManager = WluperLogManager(_wluperLog, log_api);
    }

    fun startListening() {
        session_id = UUID.randomUUID().toString();
        speechRecognizer.startListening(voiceIntent)
         wluperLogManager?.let{
             it.post_event(WluperLogKey.ASR_KEY,WluperLogKey.ASR_START_LISTENING, session_id)
         }
    }

    fun cancelListening(){
        speechRecognizer.cancel()
        listener.WluperLiveText("")
        spokenText=""
        wluperLogManager?.let{
            it.post_event(WluperLogKey.ASR_KEY,WluperLogKey.ASR_CANCEL_LISTENING, session_id)
        }
    }

    fun wluperTU(text:String){
        val bodyUnderstand = BodyUnderstand( query = text)
        val call: DisposableSingleObserver<Any> = tu_api.understand(bodyUnderstand)
        .subscribeOn(Schedulers.io())
        .observeOn(AndroidSchedulers.mainThread())
        .subscribeWith(object : DisposableSingleObserver<Any>(){
            override fun onSuccess(value: Any) {
                listener.WluperTree(value)
                wluperLogManager?.let{
                    it.post_event(WluperLogKey.NLU_KEY,value.toString(), session_id)
                }
            }
            override fun onError(e: Throwable) {
                listener.WluperError(e!!.message.toString())
                wluperLogManager?.let{
                    it.post_event(WluperLogKey.NLU_ERROR_KEY,e!!.message.toString(), session_id)
                }
            }
          }
        )
    }

    override fun onResults(results: Bundle?) {
        spokenText = getText(results)
        if (spokenText!="") {
            listener.WluperLiveText(spokenText)
        }
    }

    override fun onError(error: Int) {
        listener.WluperError("SpeechRecognizer: "+error)
        wluperLogManager?.let{
            it.post_event(WluperLogKey.ASR_ERROR_KEY,"SpeechRecognizer: "+error, session_id)
        }
    }

    override fun onReadyForSpeech(params: Bundle?) {
        listener.WluperASR("SpeechRecognizer: onReadyForSpeech");
        wluperLogManager?.let{
            it.post_event(WluperLogKey.ASR_KEY,WluperLogKey.ASR_READY_TO_SPEECH, session_id)
        }
    }

    override fun onBeginningOfSpeech() {}

    override fun onRmsChanged(rmsdB: Float) {}

    override fun onBufferReceived(buffer: ByteArray?) {}

    override fun onEndOfSpeech() {
        listener.WluperEndOfSpeech()
        wluperLogManager?.let{
            it.post_event(WluperLogKey.ASR_KEY,WluperLogKey.ASR_END_OF_SPEECH, session_id)
        }
    }

    override fun onPartialResults(partialResults: Bundle?) {
        spokenText = getText(partialResults)
        if (spokenText!="") {
            listener.WluperLiveText(spokenText)
        }
    }

    override fun onEvent(eventType: Int, params: Bundle?) { }

    private fun getText(speechBundle: Bundle?) : String {
        val userSaid = speechBundle?.getStringArrayList(SpeechRecognizer.RESULTS_RECOGNITION)
        return userSaid?.get(0) as String?: ""
    }


}
